==> uqbar-0.1.0.tar.gz: uqbar-0.1.0/setup.py <==
#!/usr/bin/env python
import pathlib
import setuptools


package_name = 'uqbar'


def read_version():
    root_path = pathlib.Path(__file__).parent
    version_path = root_path / package_name / 'version.py'
    with version_path.open() as file_pointer:
        file_contents = file_pointer.read()
    local_dict = {}
    exec(file_contents, None, local_dict)
    return local_dict['__version__']


description = 'Tools for building documentation with Sphinx, Graphviz and LaTeX'

classifiers = [
    'Development Status :: 3 - Alpha',
    'Environment :: Console',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: MIT License',
    'Natural Language :: English',
    'Operating System :: MacOS',
    'Operating System :: POSIX',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    ]

install_requires = [
    'Sphinx>=1.4.0',
    'cython',
    ]

keywords = [
    'sphinx',
    'graphviz',
    'latex',
    'documentation',
    ]

with open('README.md', 'r') as file_pointer:
    long_description = file_pointer.read()

version = read_version()

if __name__ == '__main__':
    setuptools.setup(
        author='Josiah Wolf Oberholtzer',
        author_email='josiah.oberholtzer@gmail.com',
        classifiers=classifiers,
        description=description,
        include_package_data=True,
        install_requires=install_requires,
        keywords=keywords,
        long_description=description,
        name=package_name,
        packages=[package_name],
        url='https://github.com/josiah-wolf-oberholtzer/uqbar',
        version=version,
        zip_safe=False,
        )

==> uqbar-0.2.0.tar.gz: uqbar-0.2.0/setup.py <==
#!/usr/bin/env python
import pathlib
import setuptools


package_name = 'uqbar'


def read_version():
    root_path = pathlib.Path(__file__).parent
    version_path = root_path / package_name / '_version.py'
    with version_path.open() as file_pointer:
        file_contents = file_pointer.read()
    local_dict = {}
    exec(file_contents, None, local_dict)
    return local_dict['__version__']


description = 'Tools for building documentation with Sphinx, Graphviz and LaTeX'

classifiers = [
    'Development Status :: 3 - Alpha',
    'Environment :: Console',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: MIT License',
    'Natural Language :: English',
    'Operating System :: MacOS',
    'Operating System :: POSIX',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    ]

install_requires = [
    'Sphinx>=1.6.0',
    'Unidecode>=0.4.21',
    'sphinx-autodoc-typehints>=1.2.3',
    'sphinx-rtd-theme>=0.2.4',
    ]

keywords = [
    'sphinx',
    'graphviz',
    'latex',
    'documentation',
    ]

with open('README.md', 'r') as file_pointer:
    long_description = file_pointer.read()

version = read_version()

if __name__ == '__main__':
    setuptools.setup(
        author='Josiah Wolf Oberholtzer',
        author_email='josiah.oberholtzer@gmail.com',
        classifiers=classifiers,
        description=description,
        include_package_data=True,
        install_requires=install_requires,
        keywords=keywords,
        long_description=description,
        name=package_name,
        packages=[package_name],
        url='https://github.com/josiah-wolf-oberholtzer/uqbar',
        version=version,
        zip_safe=False,
        )
